/*

  Load Cell Amplifier HX711 (Green Model)

  Parts required:
  - Arduino Board
  - Load Cell Amplifier HX711 (Green Model)
  - Load Cell (4 connectors any weight)

  Libraries:
  - HX711 Arduino Library - Version 0.7.2 or newer

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 4 Feb 2020
  Version : v1.0

  Modulet kan købes hos www.arduinotech.dk

  INFO: The program is only showing a reading to see if the loadcell works or not
        for more loadcell programming look under examples HX711.

*/

#include "HX711.h"                                    // include library HX711 version 0.7.2 or later

const int LOADCELL_DOUT_PIN = 2;                      // set loadcell dout pin as digital port 2
const int LOADCELL_SCK_PIN = 3;                       // set loadcell sck pin as digital port 3

HX711 scale;                                          // create object from library HZ711 as scale

void setup() {
  Serial.begin(9600);                                 // start Serial Monitor communication
  scale.begin(LOADCELL_DOUT_PIN, LOADCELL_SCK_PIN);   // set pinout and begin scale
}

void loop() {

  delay(500);                                         // wait 500ms for HX711 to start up

  if (scale.is_ready()) {                             // if HX711 is ready do
    long reading = scale.read();                      // read weight from HX711 and store in reading
    Serial.print("HX711 reading: ");                  // print text to Serial Monitor
    Serial.println(reading);                          // print reading value to Serial Monitor
  } else {                                            // if HX711 is not ready do
    Serial.println("HX711 not found.");               // print text to Serial Monitor
  }
  delay(1000);                                        // wait 1000ms
}
